/* eslint-disable */
import './public-path';
import "core-js/stable";
import "regenerator-runtime/runtime";
import 'dom4';
import { dirname, basename, extname } from 'path';
import { getCurrentTheme, setPropManifestToWindow } from './utils';

import { Settings } from '@ewizardjs/settings';

import App from '@/App.vue';
import * as packageJson from '@/package.json';

window.__components = window.__components || [];
window.__localBlocks = [];
window.__blocks = [];
window.__blocksList = [];
window.__blocksGroups = [];
window.__blocksFilters = [];
window.__brandsList = [];
window.__componentsList = [];
window.__modulesList = [];
window.__componentsFileProps = {};
window.__installedComponents = {};

if (
  process.env.CONTENT_TYPE === ContentTypes.EMAIL ||
  process.env.CONTENT_TYPE === ContentTypes.SITE ||
  process.env.CONTENT_TYPE === ContentTypes.MESSENGER_AD
) {
  if (process.env.BLOCKS_MANIFEST) {
    const blocksManifest = require(process.env.BLOCKS_MANIFEST);

    setPropManifestToWindow(blocksManifest, 'components', '__blocksList');
    setPropManifestToWindow(blocksManifest, 'groups', '__blocksGroups');
    setPropManifestToWindow(blocksManifest, 'filters', '__blocksFilters');
    setPropManifestToWindow(blocksManifest, 'brands', '__brandsList');
  }
  if (process.env.COMPONENTS_MANIFEST) {
    const componentsManifest = require(process.env.COMPONENTS_MANIFEST);
    window.__componentsList = window.__componentsList.concat(componentsManifest.components);
  }
  if (process.env.MODULES_MANIFEST) {
    const modulesManifest = require(process.env.MODULES_MANIFEST);
    window.__modulesList = window.__modulesList.concat(modulesManifest.components || []);
  }
  if (process.env.COMPONENT_FILE_PROPS) {
    window.__componentsFileProps = process.env.COMPONENT_FILE_PROPS;
  }

  if (window.__blocksList) {
    window.__blocksList.forEach(requireBlock);
    window.__blocksList = window.__blocksList.map(importAllIconsToBlock);
  }
  if (window.__modulesList) {
    window.__modulesList.forEach(requireBlock);
  }

  const blocksContext = require.context(process.env.LOCAL_BLOCKS, true, /index\.vue$/);

  blocksContext.keys().forEach((filePath) => {
    const blockModule = blocksContext(filePath);
    const block = blockModule.default || blockModule;
    window.__components.push(block);
  });
} else if (
  process.env.CONTENT_TYPE === ContentTypes.EDETAILER ||
  process.env.CONTENT_TYPE === ContentTypes.SURVEY
) {
  if (process.env.COMPONENTS_MANIFEST) {
    const componentsManifest = require(process.env.COMPONENTS_MANIFEST);
    window.__componentsList = window.__componentsList.concat(componentsManifest.components);
  }

  const structure = require('@/structure.json');
  Object.keys(structure.slides).forEach((slideId) => {
    const slideObj = structure.slides[slideId];
    const normalizedTemplatePath = basename(dirname(slideObj.template));
    const slideModule = require(`@/slides/${normalizedTemplatePath}/index.vue`);
    const slide = slideModule.default || slideModule;
    slide.slideId = slideId;
    window.__components.push(slide);
  });
} else if ( process.env.CONTENT_TYPE === ContentTypes.JOURNEY ) {
  if (process.env.COMPONENTS_MANIFEST) {
    const componentsManifest = require(process.env.COMPONENTS_MANIFEST);
    window.__componentsList = window.__componentsList.concat(componentsManifest.components);
  }
}

if (packageJson) {
  window.__installedComponents = getInstalledComponents();
}

window.__components.push(mergeTheme(App));

function mergeTheme(App) {
  const settings = new Settings();
  try {
    const theme = require('@/' +
      EWIZARDJS.SYSTEM_SETTINGS.path.themes +
      '/' +
      getCurrentTheme(settings)).default;
    return Object.assign(App, { theme });
  } catch (e) {
    return App;
  }
}

function requireBlock({ id }) {
  const blockModule = require(`${process.env.LIBRARY_BLOCKS}/${id}/index.vue`);
  const block = blockModule.default || blockModule;

  if (block.methods) {
    replaceMethods(block);
  }

  window.__blocks.push(block);
}

function replaceMethods(block) {
  Object.keys(block.methods).forEach((method) => {
    const methodFunction = block.methods[method];
    block.methods[method] = function(...args) {
      console.error(`Methods are not supported in Block content type`);
      return methodFunction.call(this, args);
    };
  });
}

function getInstalledComponents() {
  return Object.keys(packageJson.dependencies || {}).reduce(function(data, key) {
    data[key] = {
      path: './node_modules/' + key,
    };
    return data;
  }, {});
}

function importAllIconsToBlock(block) {
  try {
    const icons = require.context(EWIZARDJS.SYSTEM_SETTINGS.absolutePath.blocks, true, /icon.*(png|jpe?g)$/i);

    if (typeof block.icon !== 'object') {
      block.icon = {};
    }

    icons
      .keys()
      .filter(icon => !icon.includes('node_modules'))
      .forEach(icon => {
        const iconName = basename(icon, extname(icon));
        const iconPath = icon.replace('\.', '');
        const iconBlockName = iconPath.split('/')[1];

        if (iconBlockName === block.id) {
          block.icon[iconName] = `${EWIZARDJS.SYSTEM_SETTINGS.path.blocks}${iconPath}`;
        }
      });

    return block;

  }  catch(e) {
    return block;
  }
}
