"use strict";
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.filename = void 0;
const upath_1 = require("@ewizardjs/upath");
const webpack_merge_1 = require("webpack-merge");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const plugins_1 = require("../plugins");
const utils_1 = require("../utils");
const semver_1 = require("semver");
const content_types_1 = require("@ewizardjs/content-types");
const system_settings_1 = require("@ewizardjs/system-settings");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const PLUGINS_TO_REMOVE = [
    'CleanWebpackPlugin',
    'ValidateContentPathsPlugin',
    'WebpackBarPlugin',
];
const RULES_TO_REMOVE = [
    (_a = (0, rules_1.images)({ options: {} }).test) === null || _a === void 0 ? void 0 : _a.toString(),
    (_b = (0, rules_1.media)({ options: {} }).test) === null || _b === void 0 ? void 0 : _b.toString(),
];
const addPublicPath = (p) => {
    return `(window.__publicPath || '') + ${p}`;
};
exports.filename = 'build/dev/components-list.js';
exports.default = async (presentationPath, config) => {
    const contentType = await (0, system_settings_1.getByPath)(presentationPath, 'content.type');
    const isNewComponentsList = await supportsNewComponentsList(presentationPath, contentType);
    const componentsListConfig = await getComponentsListConfig(presentationPath, contentType, { isNewComponentsList });
    const mergedConfig = (0, webpack_merge_1.mergeWithCustomize)({
        customizeArray(item1, item2, key) {
            if (key === 'plugins') {
                const defaultPlugins = item1;
                const templatesPlugins = item2;
                return (0, utils_1.removePlugins)(defaultPlugins, PLUGINS_TO_REMOVE).concat(templatesPlugins);
            }
            if (key === 'module.rules' && !isNewComponentsList) {
                const defaultRules = item1;
                const templatesRules = item2;
                return (0, utils_1.removeRules)(defaultRules, RULES_TO_REMOVE).concat(templatesRules);
            }
        },
    })(config, componentsListConfig);
    return [mergedConfig, config];
};
async function getComponentsListConfig(presentationPath, contentType, options) {
    const entry = getComponentListEntry(options.isNewComponentsList);
    const componentsProps = await (0, builder_utils_1.getComponentsFileProps)(presentationPath);
    const rulesForLegacyComponentsList = [
        (0, rules_1.images)({
            options: {
                emitFile: false,
                postTransformPublicPath: addPublicPath,
                useRequire: false,
            },
        }),
        (0, rules_1.media)({
            options: {
                emitFile: false,
                postTransformPublicPath: addPublicPath,
            },
        }),
    ];
    return {
        entry,
        mode: 'production',
        devtool: false,
        output: {
            filename: exports.filename,
            library: 'ComponentsList',
            libraryTarget: 'window',
        },
        performance: {
            hints: false,
        },
        module: {
            rules: [
                ...(options.isNewComponentsList ? [] : rulesForLegacyComponentsList),
                {
                    test: /template\.vue$/i,
                    use: [
                        {
                            loader: require.resolve('../loaders/vue-component-to-module-loader'),
                            options: Object.assign(Object.assign({}, componentsProps), { emitFile: false, useRequire: false, isNewComponentsList: options.isNewComponentsList })
                        }
                    ],
                },
            ],
        },
        plugins: [
            (0, plugins_1.cleanDestinationFolder)([(0, upath_1.join)(presentationPath, exports.filename)]),
            new plugins_1.InjectComponentsListToHtmlPlugin(presentationPath),
        ],
    };
}
const MIN_EWIZARDJS_VERSION_FOR_NEW_COMPONENTS_LIST = {
    [content_types_1.ContentTypes.EDETAILER]: '5.40.0',
    [content_types_1.ContentTypes.EMAIL]: '5.40.0',
    default: '5.42.0',
};
async function supportsNewComponentsList(presentationPath, contentType) {
    var _a;
    const minEwizardjsVersion = (_a = MIN_EWIZARDJS_VERSION_FOR_NEW_COMPONENTS_LIST[contentType]) !== null && _a !== void 0 ? _a : MIN_EWIZARDJS_VERSION_FOR_NEW_COMPONENTS_LIST.default;
    if (minEwizardjsVersion) {
        const currentEwizardjsVersion = await (0, utils_1.getEwizardjsVersion)(presentationPath);
        if ((0, semver_1.gte)(currentEwizardjsVersion, minEwizardjsVersion)) {
            return true;
        }
    }
    return false;
}
function getComponentListEntry(supportsNewComponentsList) {
    return supportsNewComponentsList
        ? require.resolve('../../assets/components-list.js')
        : require.resolve('../../assets/components-list.legacy.js');
}
//# sourceMappingURL=webpack.config.js.map