"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const ramda_1 = require("ramda");
const utils_1 = require("./utils");
async function default_1(systemSettings, presentationPath, componentsProps, currentTheme = '', layoutOptions) {
    const blocksPath = (0, ramda_1.pathOr)('', ['path', 'blocks'], systemSettings);
    const blockManifestFilePath = (0, ramda_1.pathOr)('', ['path', 'blocksManifest'], systemSettings);
    const componentsFilename = (0, ramda_1.pathOr)('', ['path', 'componentsFilename'], systemSettings);
    const componentsDirectory = (0, ramda_1.pathOr)('', ['path', 'localComponents'], systemSettings);
    const componentsManifestFilePath = (0, ramda_1.pathOr)('', ['path', 'componentsManifest'], systemSettings);
    const blocksThemesFilename = (0, ramda_1.pathOr)('', ['path', 'blocksThemes'], systemSettings);
    const componentsThemesFilename = (0, ramda_1.pathOr)('', ['path', 'componentsThemes'], systemSettings);
    const masterTemplatePath = (0, ramda_1.pathOr)('', ['path', 'masterTemplatePath'], systemSettings);
    const blockManifestPath = (0, path_1.resolve)(presentationPath, blockManifestFilePath);
    const componentsFullPath = (0, path_1.join)(componentsDirectory, componentsFilename);
    const blocksThemesPath = (0, path_1.resolve)(presentationPath, blocksThemesFilename);
    const componentsThemesPath = (0, path_1.resolve)(presentationPath, componentsThemesFilename);
    const componentManifestPath = componentsManifestFilePath
        ? (0, path_1.resolve)(presentationPath, componentsManifestFilePath)
        : (0, path_1.resolve)(presentationPath, componentsFullPath);
    return [
        {
            include: [require.resolve('../assets/compound-manifest.js')],
            use: [
                {
                    loader: require.resolve('./loaders/manifest-loader'),
                    options: {
                        blocksPath,
                        presentationPath,
                        componentsProps,
                        blockManifestPath,
                        blocksThemesPath,
                        componentsThemesPath,
                        masterTemplatePath,
                        currentTheme,
                        layoutOptions,
                        componentManifestPath: await getComponentManifestPath(presentationPath, componentManifestPath),
                    },
                },
            ],
        },
    ];
}
exports.default = default_1;
async function getComponentManifestPath(presentationPath, componentManifestPath) {
    const componentsListExists = await (0, utils_1.ensureComponentsListExists)(presentationPath);
    return componentsListExists ? '' : componentManifestPath;
}
//# sourceMappingURL=get-manifest-loaders.js.map