"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const ramda_1 = require("ramda");
const content_types_1 = require("@ewizardjs/content-types");
async function default_1(systemSettings, baseDir, componentsFileProps, pages = [], contentEntities) {
    const contentType = (0, ramda_1.pathOr)('', ['content', 'type'], systemSettings);
    const blocksDir = (0, ramda_1.pathOr)('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = (0, ramda_1.pathOr)('', ['path', 'localBlocks'], systemSettings);
    const rootComponentPath = (0, ramda_1.pathOr)('', ['path', 'rootComponent'], systemSettings);
    const { fileProps, filePathProps, componentsPackageName } = componentsFileProps;
    const loaderOptions = { baseDir, componentsFileProps, contentEntities };
    const pagesComponentPath = await getPagesComponentsPath(baseDir, pages);
    const rootComponentLoaderConfig = {
        test: new RegExp(rootComponentPath),
        use: [
            {
                loader: require.resolve('./loaders/template-loader'),
                options: {
                    baseDir,
                    fileProps,
                    filePathProps,
                    componentsPackageName,
                    componentType: 'root',
                    id: 'app',
                },
            },
        ],
    };
    const blockComponentLoaderConfig = {
        test: /index\.vue$/,
        include: [(0, path_1.resolve)(baseDir, blocksDir), (0, path_1.resolve)(baseDir, localBlocksDir)],
        use: [
            {
                loader: require.resolve('./loaders/template-loader'),
                options: {
                    baseDir,
                    filePathProps,
                    componentsPackageName,
                    componentType: 'block',
                    paths: [(0, path_1.resolve)(baseDir, blocksDir), (0, path_1.resolve)(baseDir, localBlocksDir)],
                },
            },
        ],
    };
    switch (contentType) {
        case content_types_1.ContentTypes.EMAIL:
        case content_types_1.ContentTypes.MODULE:
            return [
                blockComponentLoaderConfig,
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.SURVEY:
        case content_types_1.ContentTypes.EDETAILER:
            const slideLoaders = {
                test: /slides.*index\.vue$/,
                use: [
                    {
                        loader: require.resolve('./loaders/template-loader'),
                        options: {
                            baseDir,
                            fileProps,
                            filePathProps,
                            componentsPackageName,
                            componentType: 'slide',
                        },
                    },
                ],
            };
            return [slideLoaders, rootComponentLoaderConfig];
        case content_types_1.ContentTypes.SITE:
        case content_types_1.ContentTypes.MESSENGER_AD:
            const pageComponentLoadersConfig = {
                include: pagesComponentPath,
                use: [
                    {
                        loader: require.resolve('./loaders/template-loader'),
                        options: {
                            baseDir,
                            fileProps,
                            filePathProps,
                            componentsPackageName,
                            componentType: 'page',
                        },
                    },
                ],
            };
            return [
                blockComponentLoaderConfig,
                pageComponentLoadersConfig,
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.JOURNEY:
            return [
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.BANNER:
            return [
                getEntityComponentLoader('banner', loaderOptions),
                rootComponentLoaderConfig,
            ];
        default:
            return [];
    }
}
exports.default = default_1;
function getEntityComponentLoader(componentType, options) {
    const { baseDir, componentsFileProps, contentEntities } = options;
    const elementsComponentPath = getComponentsPath(baseDir, contentEntities);
    return {
        include: elementsComponentPath,
        use: [
            {
                loader: require.resolve('./loaders/template-loader'),
                options: Object.assign(Object.assign({}, componentsFileProps), { baseDir,
                    componentType }),
            },
        ],
    };
}
async function getPagesComponentsPath(contentPath, pages) {
    return pages.map(({ template }) => (0, path_1.resolve)(contentPath, template));
}
function getComponentsPath(contentPath, components = []) {
    return components.map(({ template }) => (0, path_1.resolve)(contentPath, template));
}
//# sourceMappingURL=get-template-loaders.js.map