"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const builder_utils_1 = require("@ewizardjs/builder-utils");
const image_loader_1 = __importDefault(require("@ewizardjs/builder-utils/dist/loaders/image-loader"));
const fs_extra_1 = require("fs-extra");
const upath_1 = require("@ewizardjs/upath");
const vue_template_compiler_1 = require("vue-template-compiler");
const utils_1 = require("../utils");
const CONFIG_JS_FILE = './ewizard.config.js';
const TEMPLATE_VUE_FILE = './ewizard.template.vue';
const CONFIG = 'config';
async function default_1(source) {
    const configPath = (0, upath_1.resolve)(this.context, CONFIG_JS_FILE);
    const exists = await (0, fs_extra_1.pathExists)(configPath);
    const customTemplatePath = (0, upath_1.resolve)(this.context, TEMPLATE_VUE_FILE);
    const customTemplateExists = await (0, fs_extra_1.pathExists)(customTemplatePath);
    if (exists) {
        const templateOptions = await getTemplateOptions(this);
        const basicReplacement = `
      ;const ${CONFIG} = require('${CONFIG_JS_FILE}').default;
      ${templateOptions}
      component.options.ewizardConfig = ${CONFIG};
      try {
      /custom-template-require-marker/;
      } catch (e) {}
      export default component.exports;`;
        const customTemplateReplacement = basicReplacement.replace('/custom-template-require-marker/', `require('${TEMPLATE_VUE_FILE}')`);
        const replacement = customTemplateExists ? customTemplateReplacement : basicReplacement;
        return source.replace('export default component.exports', replacement);
    }
    return source;
}
exports.default = default_1;
async function getTemplateOptions(context) {
    try {
        const { context: dirPath } = context;
        const templatePath = (0, upath_1.resolve)(dirPath, TEMPLATE_VUE_FILE);
        const vueFileContent = await (0, utils_1.getNormalizedVueFileContent)(templatePath);
        const { template } = (0, vue_template_compiler_1.parseComponent)(vueFileContent);
        const templateWithNormalizedPaths = template ? image_loader_1.default.call(context, template === null || template === void 0 ? void 0 : template.content) : template;
        const templateOption = getConfigProperty('template', templateWithNormalizedPaths);
        const templatePathOption = `${CONFIG}.templatePath='${TEMPLATE_VUE_FILE}';`;
        return `${templatePathOption}${templateOption}`;
    }
    catch (e) {
        return '';
    }
}
function getConfigProperty(prop, value) {
    if (value) {
        const newVal = (0, builder_utils_1.replaceSpecialCharacters)(value);
        return `${CONFIG}.${prop}='${newVal}';`;
    }
    return '';
}
//# sourceMappingURL=config-loader.js.map