"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const loader_utils_1 = require("loader-utils");
const system_settings_1 = require("@ewizardjs/system-settings");
const banner_structure_api_1 = require("@ewizardjs/banner-structure-api");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const upath_1 = require("@ewizardjs/upath");
const fs_extra_1 = require("fs-extra");
async function default_1(source) {
    const { presentationPath } = (0, loader_utils_1.getOptions)(this);
    const systemSettings = await (0, system_settings_1.get)(presentationPath);
    const templatesManifest = systemSettings.path.templatesManifest;
    const templatesJsonPath = (0, upath_1.join)(presentationPath, templatesManifest);
    const templatesJson = await (0, builder_utils_1.readManifest)(templatesJsonPath);
    const templateEntities = (0, banner_structure_api_1.getBanners)(templatesJson, { systemSettings, isTemplates: true });
    const requiredComponents = await getRequiredComponents(presentationPath, templateEntities);
    return source.replace('/#marker-component-banners/', `{${requiredComponents}}`);
}
exports.default = default_1;
async function getRequiredComponents(presentationPath, entities) {
    return Promise.all(entities.map((entity) => getRequiredComponentString(presentationPath, entity)));
}
async function getRequiredComponentString(presentationPath, { id, template, name, thumbnail }) {
    const templateThumbnail = await getThumbnailPath(presentationPath, thumbnail);
    return `'${id}':{name:'${name}',requiredComponent:require('${(0, upath_1.join)('@', template)}'),templateThumbnail:'${templateThumbnail}'}`;
}
async function getThumbnailPath(presentationPath, thumbnail) {
    try {
        const thumbPath = (0, upath_1.join)(presentationPath, thumbnail);
        await (0, fs_extra_1.access)(thumbPath, fs_extra_1.constants.F_OK);
        return thumbnail;
    }
    catch (e) {
        return '';
    }
}
//# sourceMappingURL=entry-banner-template-loader.js.map