"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const builder_utils_1 = require("@ewizardjs/builder-utils");
const cheerio_1 = __importDefault(require("cheerio"));
const content_checker_1 = require("@ewizardjs/content-checker");
const loader_utils_1 = require("loader-utils");
const path_1 = require("path");
const css_to_json_1 = __importDefault(require("@ewizardjs/css-to-json"));
const vue_template_compiler_1 = require("vue-template-compiler");
const utils_1 = require("../utils");
const clone_1 = __importDefault(require("clone"));
async function default_1(source) {
    let { baseDir, componentType, id, fileProps, filePathProps, componentsPackageName, paths, } = (0, loader_utils_1.getOptions)(this);
    if ((0, utils_1.isString)(filePathProps)) {
        filePathProps = JSON.parse(filePathProps);
    }
    const moduleBaseDir = (0, path_1.resolve)((0, path_1.join)((0, path_1.dirname)(this.resourcePath), '..'));
    if (paths && !paths.includes(moduleBaseDir))
        return source;
    const componentId = id || (0, path_1.basename)((0, path_1.dirname)(this.resourcePath));
    const resourcePath = (0, utils_1.toUnixPath)(this.resourcePath);
    const moduleFilePath = (0, utils_1.toUnixPath)((0, path_1.relative)(baseDir, resourcePath));
    const moduleDir = (0, path_1.dirname)(moduleFilePath);
    const template = await getTemplate(resourcePath, moduleDir, fileProps, filePathProps, componentsPackageName);
    const styles = await getStyles(resourcePath, componentType, moduleDir);
    const { classic } = await (0, content_checker_1.getFrameworkInfo)(baseDir);
    const config = await getConfig(resourcePath);
    return source.replace('export default component.exports', () => `;component.options.template = '${template}';
    component.options.slideId = '${componentId}';
    component.options.__componentType = '${componentType}';
    component.options.resourcePath = '${moduleFilePath}';
    ${classic
        ? ''
        : `component.options.styles = ${styles};`}
    ${`component.options.config = ${config};`}
    export default component.exports;`);
}
exports.default = default_1;
async function getConfig(filePath) {
    const vueFileContent = await (0, utils_1.getNormalizedVueFileContent)(filePath);
    const { customBlocks } = (0, vue_template_compiler_1.parseComponent)(vueFileContent, { deindent: true });
    const configBlock = customBlocks.find((block) => block.type === 'config');
    if (configBlock) {
        return configBlock.content;
    }
    return JSON.stringify({});
}
async function getTemplate(filePath, moduleDir, fileProps, filePathProps, componentsPackageName) {
    const vueFileContent = await (0, utils_1.getNormalizedVueFileContent)(filePath);
    const { template } = (0, vue_template_compiler_1.parseComponent)(vueFileContent, { deindent: true });
    if (template) {
        return setPublicPathTokenToMedia(template.content, moduleDir, fileProps, filePathProps, componentsPackageName)
            .replace(/\\/g, '\\\\')
            .replace(/`/g, '\\`')
            .replace(/'/g, "\\'")
            .replace(/\r?\n|\r/g, '')
            .replace(/>\s*</g, '><')
            .replace(/<!--(.*?)-->/g, '');
    }
}
async function getStyles(filePath, componentType, moduleDir) {
    try {
        const vueFileContent = await (0, utils_1.getNormalizedVueFileContent)(filePath);
        const { styles } = (0, vue_template_compiler_1.parseComponent)(vueFileContent, { deindent: true });
        const collectOnlyEditorStyles = hasEditorStyles(componentType);
        const processedStylesData = styles
            .filter(slideData => { var _a; return collectOnlyEditorStyles ? !!((_a = slideData.attrs) === null || _a === void 0 ? void 0 : _a.editor) : true; })
            .map((styleData) => {
            const styleDataCopy = (0, clone_1.default)(styleData);
            const isCssLang = !styleDataCopy.lang || styleDataCopy.lang === 'css';
            if (isCssLang) {
                const stylesParseOptions = {
                    parseAtRules: true,
                    atRulesGroupName: 'mobile',
                    rulesGroupName: 'desktop',
                };
                const styleWithResolvedMedia = resolveMediaInCss(styleDataCopy.content, moduleDir);
                const stylesRecord = (0, css_to_json_1.default)(styleWithResolvedMedia, stylesParseOptions);
                const mediaRules = Object.fromEntries(Object.entries(stylesRecord[stylesParseOptions.atRulesGroupName])
                    .filter(([key]) => key.startsWith('@media')));
                stylesRecord[stylesParseOptions.atRulesGroupName] = mediaRules;
                styleDataCopy.content = stylesRecord;
            }
            return styleDataCopy.content;
        });
        return JSON.stringify(processedStylesData);
    }
    catch (e) {
        return [];
    }
}
function setPublicPathTokenToMedia(template, moduleDir, fileProps = {}, filePathProps = {}, componentsPackageName) {
    const templateWithReplacedObjects = (0, builder_utils_1.replaceObjects)(template, fileProps, filePathProps, componentsPackageName, false, resolveFilePath.bind(null, moduleDir));
    const $ = cheerio_1.default.load(templateWithReplacedObjects, {
        decodeEntities: false,
        _useHtmlParser2: true,
        lowerCaseTags: false,
    });
    Object.keys(fileProps).forEach((componentName) => {
        const $tag = (0, builder_utils_1.getCheerioTag)($, componentName, componentsPackageName);
        $tag === null || $tag === void 0 ? void 0 : $tag.each((i, elem) => {
            (0, builder_utils_1.getFilePropsForElement)(elem, fileProps, componentsPackageName).forEach((prop) => {
                const currentValue = $(elem).attr(prop);
                if (currentValue === 'undefined') {
                    $(elem).attr(prop, '');
                }
                else if (currentValue && !isAbsoluteUrl(currentValue)) {
                    $(elem).attr(prop, `{publicPath}${resolveFilePath(moduleDir, (0, utils_1.encodeFilePath)(currentValue))}`);
                }
                const boundPropValue = $(elem).attr(`:${prop}`);
                if (boundPropValue && boundPropValue.startsWith("'") && !boundPropValue.includes('{publicPath}')) {
                    const matched = boundPropValue.match(/'(.+?)'/);
                    const url = matched && matched[1];
                    if (url && !isAbsoluteUrl(url)) {
                        $(elem).attr(prop, `{publicPath}${resolveFilePath(moduleDir, (0, utils_1.encodeFilePath)(url))}`);
                    }
                }
            });
        });
    });
    const mediaAttrs = ['src', 'poster', 'href', 'xlink:href'];
    $('video,source,img,image,use').each((i, elem) => {
        Object.entries(elem.attribs).forEach(([attr, value]) => {
            if (mediaAttrs.includes(attr)) {
                $(elem).attr(attr, `{publicPath}${resolveFilePath(moduleDir, (0, utils_1.encodeFilePath)(value))}`);
            }
        });
    });
    return $.html();
}
function resolveMediaInCss(css, moduleDir) {
    return css.replace(/url\(['"]?(.+?)['"]?\)/g, (match, url) => {
        if (isAbsoluteUrl(url)) {
            return match;
        }
        const resolvedUrl = resolveFilePath(moduleDir, (0, utils_1.encodeFilePath)(url));
        return `url(${resolvedUrl})`;
    });
}
function resolveFilePath(moduleDir, value) {
    if (value.includes(moduleDir)) {
        return value;
    }
    return (0, utils_1.toUnixPath)((0, path_1.join)(moduleDir, value));
}
function isAbsoluteUrl(url) {
    return /^https?:/.test(url);
}
function hasEditorStyles(componentType) {
    var _a;
    const EDITOR_COMPONENTS = {
        root: true,
        slide: true,
        page: true,
        banner: true,
    };
    return (_a = EDITOR_COMPONENTS[componentType]) !== null && _a !== void 0 ? _a : false;
}
//# sourceMappingURL=template-loader.js.map