"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Builder = void 0;
const builder_utils_1 = require("@ewizardjs/builder-utils");
const path_1 = require("path");
const webpack_1 = __importDefault(require("webpack"));
const webpack_config_1 = __importDefault(require("../componentsList/webpack.config"));
const webpack_config_2 = __importDefault(require("../layout/webpack.config"));
const webpack_config_3 = __importDefault(require("../templates/webpack.config"));
const utils_1 = require("../utils");
require("@ewizardjs/builder-utils/dist/modules/patchCryptoCreateHash");
class Builder {
    constructor(presentationPath) {
        this.options = {
            presentationPath,
            destinationPath: presentationPath,
            clm: 'dev',
        };
    }
    getDevConfig(options) {
        const strategiesPath = (0, path_1.resolve)(__dirname, '..', 'strategies');
        return (0, builder_utils_1.getConfig)(strategiesPath, Object.assign(Object.assign({}, this.options), options));
    }
    async getTemplatesConfig(options) {
        const devConfig = await this.getDevConfig(options);
        return (0, webpack_config_3.default)(this.options.presentationPath, devConfig);
    }
    async getConfigWithComponentsListLibrary(options, baseConfig) {
        const componentsListExists = await (0, utils_1.ensureComponentsListExists)(this.options.presentationPath);
        const devConfig = baseConfig !== null && baseConfig !== void 0 ? baseConfig : await this.getDevConfig(options);
        if (!componentsListExists) {
            return [devConfig];
        }
        return (0, webpack_config_1.default)(this.options.presentationPath, devConfig);
    }
    async getLayoutConfig(options) {
        const devConfig = await this.getDevConfig(options);
        return (0, webpack_config_2.default)(this.options.presentationPath, devConfig, options);
    }
    async getCompiler(options) {
        if (options.layout) {
            const layoutConfig = await this.getLayoutConfig(options);
            const componentJsConfigs = await this.getConfigWithComponentsListLibrary(options, layoutConfig);
            return (0, webpack_1.default)([layoutConfig, ...componentJsConfigs]);
        }
        if (options.template) {
            const config = await Promise.all([
                this.getTemplatesConfig(Object.assign(Object.assign({}, options), { validate: false })),
                ...await this.getConfigWithComponentsListLibrary(options),
            ]);
            return (0, webpack_1.default)(config);
        }
        const configs = await this.getConfigWithComponentsListLibrary(options);
        if (options.watch) {
            configs.forEach(config => config.watch = options.watch);
        }
        return (0, webpack_1.default)(configs);
    }
}
exports.Builder = Builder;
//# sourceMappingURL=builder.js.map