"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildWatcher = void 0;
const rx_1 = require("rx");
const path_1 = require("path");
const builder_1 = require("./builder");
const componentsBuilder_1 = require("./componentsBuilder");
const layoutsBuilder_1 = require("./layoutsBuilder");
class BuildWatcher extends builder_1.Builder {
    constructor(presentationPath, contentType) {
        super(presentationPath);
        this.presentationPath = presentationPath;
        this.contentType = contentType;
    }
    start(options) {
        if (!this.watcher$ || (this.watcher$ && this.watcher$.source.isStopped)) {
            const watcher = this.createWatcher({
                ignored: [/node_modules/, (0, path_1.join)(this.presentationPath, 'index.html')],
            });
            const componentsBuilder = new componentsBuilder_1.ComponentsBuilder(this.presentationPath);
            const layoutsBuilder = new layoutsBuilder_1.LayoutsBuilder(this.presentationPath);
            const componentsConfig$ = rx_1.Observable.fromPromise(componentsBuilder.getCompiler(options));
            const layoutsConfig$ = rx_1.Observable.fromPromise(layoutsBuilder.getCompiler(options));
            const devConfig$ = rx_1.Observable.fromPromise(this.getCompiler(Object.assign({ watch: true }, options)));
            return devConfig$
                .combineLatest(componentsConfig$, layoutsConfig$)
                .map(([compiler, componentsConfig, layoutsConfig]) => {
                if (this.contentType === 'module') {
                    return componentsConfig;
                }
                if (options.layout) {
                    return layoutsConfig;
                }
                return compiler;
            })
                .map((compiler) => watcher(compiler))
                .mergeAll();
        }
        return this.watcher$;
    }
    stop() {
        return rx_1.Observable.fromCallback(this.watcher.close, this.watcher)().toPromise();
    }
    createWatcher(options) {
        return (compiler) => {
            const stats$ = new rx_1.Subject();
            compiler.hooks.watchClose.tap('stop', () => stats$.onCompleted());
            compiler.hooks.watchRun.tap('newRun', () => {
                stats$.onNext(null);
            });
            this.watcher = compiler.watch(options, (err, stats) => {
                if (err) {
                    stats$.onError(err);
                }
                else {
                    stats$.onNext(stats);
                }
            });
            return (this.watcher$ = stats$.asObservable());
        };
    }
}
exports.BuildWatcher = BuildWatcher;
//# sourceMappingURL=watcher.js.map