"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InjectCommonChunksPlugin = void 0;
const webpack_config_1 = require("../templates/webpack.config");
const InjectHtmlPlugin_1 = require("./InjectHtmlPlugin");
const PLUGIN_NAME = 'InjectCommonChunksPlugin';
const INDEX = 'index.html';
const CHUNK_PREFIX = 'common';
const APP_JS = '[src="./build/dev/app.js"]';
const IS_COMMON_CHUNK_ATTRIBUTE = 'data-is-common-chunk';
function chunkToPath(chunk) {
    const fileName = chunk.files[0];
    return fileName.startsWith('./') ? fileName : `./${fileName}`;
}
class InjectCommonChunksPlugin extends InjectHtmlPlugin_1.InjectHtmlPlugin {
    apply(compiler) {
        compiler.hooks.emit.tapPromise(PLUGIN_NAME, async (compilation) => {
            if (this.isTemplatesBuild(compilation)) {
                return;
            }
            await this.ensureIndexAssetExists(compilation);
            const $ = this.getParsedHtml(compilation, INDEX);
            this.cleanHtmlFromChunks($);
            const chunks = this.getCommonChunks(compilation);
            if (!chunks.length) {
                return;
            }
            const chunkPaths = chunks.map(chunkToPath);
            this.appendChunksToHtml(compilation, $, chunkPaths);
            this.updateAsset(compilation, INDEX, $.html({ normalizeWhitespace: true }));
            this.updateAsset(compilation, 'build/dev/common-chunks-list.js', `window.__commonChunksList = [${chunkPaths.map(chunkPath => `'${chunkPath}'`).join(',')}]`);
        });
    }
    isTemplatesBuild(compilation) {
        return Boolean(compilation.assets[webpack_config_1.filename]);
    }
    async ensureIndexAssetExists(compilation) {
        try {
            await super.ensureAssetExists(compilation, INDEX);
        }
        catch (_a) {
            const errorMessage = `${PLUGIN_NAME}: there is no html file to inject chunks`;
            compilation.errors.push(errorMessage);
            throw new Error(errorMessage);
        }
    }
    cleanHtmlFromChunks($) {
        $(`[${IS_COMMON_CHUNK_ATTRIBUTE}]`).remove();
    }
    getCommonChunks(compilation) {
        return compilation.chunks.filter((chunk) => chunk.name.startsWith(CHUNK_PREFIX));
    }
    appendChunksToHtml(compilation, $, chunks) {
        const prependToElement = $(APP_JS);
        if (!prependToElement) {
            const error = `${PLUGIN_NAME}: there is no app.js script in index.html`;
            compilation.errors.push(error);
            throw new Error(error);
        }
        chunks.forEach((pathToChunk) => {
            prependToElement
                .before(`<script src="${pathToChunk}" ${IS_COMMON_CHUNK_ATTRIBUTE}></script>`);
        });
    }
}
exports.InjectCommonChunksPlugin = InjectCommonChunksPlugin;
//# sourceMappingURL=InjectCommonChunksPlugin.js.map