"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InjectHtmlPlugin = void 0;
const cheerio_1 = __importDefault(require("cheerio"));
const fs_extra_1 = require("fs-extra");
const upath_1 = require("@ewizardjs/upath");
class InjectHtmlPlugin {
    constructor(presentationPath) {
        this.presentationPath = presentationPath;
    }
    getParsedHtml(compilation, assetName) {
        const htmlContent = compilation.assets[assetName].source();
        return cheerio_1.default.load(htmlContent, {
            decodeEntities: false,
            _useHtmlParser2: true,
            lowerCaseTags: false,
        });
    }
    async ensureAssetExists(compilation, assetName) {
        if (!compilation.assets[assetName]) {
            const assetPath = (0, upath_1.join)(this.presentationPath, assetName);
            const content = await (0, fs_extra_1.readFile)(assetPath, 'utf8');
            this.updateAsset(compilation, assetName, content);
        }
    }
    updateAsset(compilation, assetName, content) {
        compilation.assets[assetName] = {
            source() {
                return content;
            },
            size() {
                return this.source().length;
            },
        };
    }
}
exports.InjectHtmlPlugin = InjectHtmlPlugin;
//# sourceMappingURL=InjectHtmlPlugin.js.map