"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineDevSettings = void 0;
const fs_extra_1 = require("fs-extra");
const content_types_1 = require("@ewizardjs/content-types");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const path_1 = require("path");
const ramda_1 = require("ramda");
const plugins_1 = require("@ewizardjs/builder-utils/plugins");
async function defineDevSettings(options, systemSettings) {
    const presentationPath = options.presentationPath;
    const blocksDir = (0, ramda_1.pathOr)('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = (0, ramda_1.pathOr)('', ['path', 'localBlocks'], systemSettings);
    const componentsManifestFilePath = (0, ramda_1.pathOr)('', ['path', 'componentsManifest'], systemSettings);
    const componentsManifestFileName = (0, ramda_1.pathOr)('', ['path', 'componentsFilename'], systemSettings);
    const blocksManifestFileName = (0, ramda_1.pathOr)('', ['path', 'blocksManifest'], systemSettings);
    const modulesManifestFileName = (0, ramda_1.pathOr)('', ['path', 'modulesManifest'], systemSettings);
    const blocksThemesFileName = (0, ramda_1.pathOr)('', ['path', 'blocksThemes'], systemSettings);
    const componentsThemesFileName = (0, ramda_1.pathOr)('', ['path', 'componentsThemes'], systemSettings);
    const componentsDir = (0, ramda_1.pathOr)('', ['path', 'localComponents'], systemSettings);
    const slidesDir = (0, ramda_1.pathOr)('', ['path', 'slides'], systemSettings);
    const { fileProps } = await (0, builder_utils_1.getComponentsFileProps)(presentationPath);
    const localBlocksPath = (0, path_1.resolve)(presentationPath, localBlocksDir);
    const libraryBlocksPath = (0, path_1.resolve)(presentationPath, blocksDir);
    const blocksManifestPath = (0, path_1.resolve)(presentationPath, blocksManifestFileName);
    const modulesManifestPath = (0, path_1.resolve)(presentationPath, modulesManifestFileName);
    const blocksThemesManifestPath = (0, path_1.resolve)(presentationPath, blocksThemesFileName);
    const componentsThemesManifestPath = (0, path_1.resolve)(presentationPath, componentsThemesFileName);
    const structureJsonPath = (0, path_1.resolve)(presentationPath, 'structure.json');
    const componentsManifestPath = componentsManifestFilePath
        ? (0, path_1.resolve)(presentationPath, componentsManifestFilePath)
        : (0, path_1.resolve)(presentationPath, componentsDir, componentsManifestFileName);
    const [componentsManifestExists, blocksManifestExists, modulesManifestExists, blocksThemesManifestExists, componentsThemesManifestExists,] = await Promise.all([
        (0, fs_extra_1.pathExists)(componentsManifestPath),
        (0, fs_extra_1.pathExists)(blocksManifestPath),
        (0, fs_extra_1.pathExists)(modulesManifestPath),
        (0, fs_extra_1.pathExists)(blocksThemesManifestPath),
        (0, fs_extra_1.pathExists)(componentsThemesManifestPath),
    ]);
    const pluginContentTypes = Object.keys(content_types_1.ContentTypes).reduce((obj, key) => (Object.assign(Object.assign({}, obj), { [key]: JSON.stringify(content_types_1.ContentTypes[key]) })), {});
    const structureJson = await getStructureJSON(structureJsonPath);
    const plugin = (0, plugins_1.defineSettings)(presentationPath, systemSettings, 'dev', false, structureJson === null || structureJson === void 0 ? void 0 : structureJson.structureFileVersion);
    plugin.definitions['process.env'] = Object.assign(Object.assign({}, plugin.definitions['process.env']), { LOCAL_BLOCKS: JSON.stringify(localBlocksPath), LIBRARY_BLOCKS: JSON.stringify(libraryBlocksPath), COMPONENTS_MANIFEST: JSON.stringify(componentsManifestExists ? componentsManifestPath : ''), BLOCKS_MANIFEST: JSON.stringify(blocksManifestExists ? blocksManifestPath : ''), BLOCKS_THEMES_MANIFEST: JSON.stringify(blocksThemesManifestExists ? blocksThemesManifestPath : ''), COMPONENTS_THEMES_MANIFEST: JSON.stringify(componentsThemesManifestExists ? componentsThemesManifestPath : ''), MODULES_MANIFEST: JSON.stringify(modulesManifestExists ? modulesManifestPath : ''), SLIDES_DIR: JSON.stringify((0, path_1.resolve)(presentationPath, slidesDir)), COMPONENT_FILE_PROPS: JSON.stringify(fileProps) });
    plugin.definitions.ContentTypes = pluginContentTypes;
    return plugin;
}
exports.defineDevSettings = defineDevSettings;
async function getStructureJSON(structureJsonPath) {
    try {
        return await (0, fs_extra_1.readJSON)(structureJsonPath);
    }
    catch (error) { }
}
//# sourceMappingURL=defineDevSettings.js.map