"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatsLogPlugin = exports.statsLog = void 0;
function statsLog() {
    return new StatsLogPlugin();
}
exports.statsLog = statsLog;
class StatsLogPlugin {
    apply(compiler) {
        compiler.hooks.done.tap('StatsLogPlugin', (stats) => {
            console.log(stats.toString({
                warningsFilter,
                colors: true,
                builtAt: false,
                children: false,
                modules: false,
                moduleTrace: false,
                assets: false,
                chunks: false,
                chunkModules: false,
                timings: false,
                version: false,
                hash: false,
                entrypoints: false,
                publicPath: false,
                depth: false,
            }));
        });
    }
}
exports.StatsLogPlugin = StatsLogPlugin;
function warningsFilter(warning) {
    const tsDeclarations = /TypeScript declaration files should never be required/;
    if (tsDeclarations.test(warning)) {
        return true;
    }
    const eslintNoFile = /Module build failed \(from.+[\/\\]eslint-loader[\/\\]index\.js\):\s*Error: ENOENT: no such file or directory, open/;
    if (eslintNoFile.test(warning)) {
        return true;
    }
    const nameDuplicates = /There are multiple modules with names that only differ in casing./gi;
    if (nameDuplicates.test(warning)) {
        return true;
    }
    const settingsDeclarations = /node_modules\/(@ewizardjs\/)?settings\/.*\.d\.ts/;
    if (settingsDeclarations.test(warning)) {
        return true;
    }
    return false;
}
//# sourceMappingURL=statsLog.js.map