"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const alias_resolver_1 = require("@ewizardjs/alias-resolver");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const aliases_1 = require("@ewizardjs/builder-utils/aliases");
const plugins_1 = require("@ewizardjs/builder-utils/plugins");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ramda_1 = require("ramda");
const webpack_merge_1 = require("webpack-merge");
const enums_1 = require("../../enums");
const get_config_loaders_1 = __importDefault(require("../../get-config-loaders"));
const get_manifest_loaders_1 = __importDefault(require("../../get-manifest-loaders"));
const get_plugins_loaders_1 = __importDefault(require("../../get-plugins-loaders"));
const get_style_loaders_1 = __importDefault(require("../../get-style-loaders"));
const get_template_loaders_1 = __importDefault(require("../../get-template-loaders"));
const plugins_2 = require("../../plugins");
async function default_1(options) {
    const { presentationPath, systemSettings, target, componentsProps, currentTheme, validate, pages, contentEntities, } = options;
    const blocksDir = (0, ramda_1.pathOr)('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = (0, ramda_1.pathOr)('', ['path', 'localBlocks'], systemSettings);
    const localBlocksPath = (0, path_1.resolve)(presentationPath, localBlocksDir);
    const libraryBlocksPath = (0, path_1.resolve)(presentationPath, blocksDir);
    const masterTemplatePath = (0, ramda_1.pathOr)('', ['path', 'masterTemplatePath'], systemSettings);
    await Promise.all([(0, fs_extra_1.mkdirp)(localBlocksPath), (0, fs_extra_1.mkdirp)(libraryBlocksPath)]);
    const layoutOptions = {
        masterTemplatePath,
        layoutsDir: (0, ramda_1.pathOr)('', ['path', 'layouts'], systemSettings),
        layoutName: (0, ramda_1.pathOr)('', ['path', 'masterTemplateLayout'], systemSettings),
    };
    const builderPath = (0, path_1.resolve)(__dirname, '../../../');
    const webpackDevLoaders = await (0, builder_utils_1.getWebpackDevRules)(presentationPath);
    const commonPlugins = [
        (0, plugins_1.fallbackResource)(),
        (0, plugins_1.vueLoader)(),
        (0, plugins_1.slideThumbReplacement)(systemSettings),
        await (0, plugins_2.defineDevSettings)(options, systemSettings),
        await (0, plugins_1.bannerForAssets)({ include: /js$/ }, builderPath, presentationPath, 'ewizardjs'),
        new plugins_1.ValidateContentPathsPlugin(presentationPath),
    ];
    const devConfig = {
        mode: 'development',
        context: presentationPath,
        optimization: {},
        devtool: false,
        output: {
            path: presentationPath,
            hashFunction: 'sha256',
        },
        resolveLoader: {
            modules: [(0, path_1.join)(__dirname, '../../loaders'), ...(module.paths || [])],
        },
        resolve: {
            extensions: ['.webpack.js', '.web.js', '.ts', '.tsx', '.js'],
            alias: (0, aliases_1.getAliases)(presentationPath),
            modules: ['node_modules', (0, path_1.resolve)(presentationPath, 'node_modules')],
            symlinks: false,
            plugins: [new alias_resolver_1.DynamicAliasResolvePlugin(presentationPath, layoutOptions)],
        },
        module: {
            rules: [
                ...(await (0, get_template_loaders_1.default)(systemSettings, presentationPath, componentsProps, pages, contentEntities)),
                ...(await (0, get_style_loaders_1.default)(systemSettings, presentationPath)),
                ...(0, get_plugins_loaders_1.default)((0, ramda_1.pathOr)({}, ['plugins'], systemSettings), options),
                ...(0, get_config_loaders_1.default)(Object.assign(Object.assign({}, componentsProps), { emitFile: false, useRequire: false })),
                ...(await (0, get_manifest_loaders_1.default)(systemSettings, presentationPath, componentsProps, currentTheme, layoutOptions)),
            ],
        },
        plugins: target === enums_1.Target.Ewizard
            ? [...commonPlugins]
            : [(0, plugins_1.progressBar)(), (0, plugins_2.statsLog)(), ...commonPlugins],
    };
    if (options.target !== enums_1.Target.Ewizard) {
        webpackDevLoaders.module.rules.push((0, rules_1.validation)({ validateHtml: validate }));
    }
    else {
        devConfig.optimization = {
            minimize: true,
            minimizer: [(0, plugins_2.getJsMinimizer)()],
        };
    }
    if (options.debug) {
        devConfig.devtool = 'eval-source-map';
        devConfig.optimization = Object.assign(Object.assign({}, (devConfig.optimization)), { minimize: false });
    }
    return (0, webpack_merge_1.merge)(devConfig, webpackDevLoaders);
}
exports.default = default_1;
//# sourceMappingURL=webpack.config.js.map