"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const builder_utils_1 = require("@ewizardjs/builder-utils");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const content_checker_1 = require("@ewizardjs/content-checker");
const content_types_1 = require("@ewizardjs/content-types");
const settings_1 = require("@ewizardjs/settings");
const upath_1 = require("@ewizardjs/upath");
const webpack_merge_1 = require("webpack-merge");
const get_entry_common_loader_1 = __importDefault(require("../../get-entry-common-loader"));
const content_type_loader_1 = require("../../loaders/content-type-loader");
const plugins_1 = require("../../plugins");
const rules_2 = require("../../rules");
const webpack_config_1 = require("../../templates/webpack.config");
const webpack_config_2 = require("../../components/webpack.config");
const webpack_config_3 = __importDefault(require("../bubbles/webpack.config"));
const webpack_config_4 = require("../../componentsList/webpack.config");
exports.default = async (options) => {
    const baseConfig = await (0, webpack_config_3.default)(options);
    const { presentationPath, systemSettings, pages, contentEntities, currentTheme: currentThemeName = await (0, settings_1.getCurrentTheme)(presentationPath), } = options;
    const { type: contentType } = systemSettings.content;
    const { themesManifest, themes } = systemSettings.path;
    const isModule = contentType === content_types_1.ContentTypes.MODULE;
    const isNotEdetailer = contentType !== content_types_1.ContentTypes.EDETAILER;
    const isBlocksListNeeded = isNotEdetailer && !options.layout;
    const isBanner = contentType === content_types_1.ContentTypes.BANNER;
    const entities = isBanner ? contentEntities : pages;
    const themesList = isBlocksListNeeded
        ? await (0, builder_utils_1.getThemesList)(presentationPath, themesManifest, themes)
        : [];
    const currentBlocksList = isBlocksListNeeded
        ? (0, builder_utils_1.getCurrentBlocks)(presentationPath, systemSettings)
        : [];
    const uniqueBlocksList = isBlocksListNeeded
        ? await (0, builder_utils_1.getDynamicBlocksList)({ presentationPath, systemSettings, pages: entities }, currentBlocksList)
        : [];
    const cleanPatterns = [
        (0, upath_1.join)(presentationPath, 'build/dev/**/*'),
        `!${(0, upath_1.join)(presentationPath, webpack_config_4.filename)}`,
    ];
    options.template && cleanPatterns.push(`!${(0, upath_1.join)(presentationPath, webpack_config_1.filename)}`);
    isModule && cleanPatterns.push(`!${(0, upath_1.join)(presentationPath, webpack_config_2.filename)}`);
    const cornConfig = {
        entry: {
            app: [require.resolve('../../../assets/entry-common'), options.appEntryPath],
            index: options.indexEntryPath,
            editor: require.resolve('../../../assets/entry-editor'),
        },
        optimization: {
            splitChunks: {
                hidePathInfo: true,
                cacheGroups: {
                    common: {
                        name: 'common',
                        chunks: 'all',
                        minSize: 1310720,
                        maxSize: 5242880,
                        minChunks: 2,
                    },
                },
            },
        },
        module: {
            rules: [
                (0, rules_1.getPageComponents)(presentationPath, systemSettings, true, true),
                (0, rules_1.getContentEntityComponents)({ systemSettings }),
                ...(0, content_type_loader_1.getContentTypeLoader)({
                    include: /node_modules/,
                }),
                (0, get_entry_common_loader_1.default)(presentationPath),
                (0, rules_1.currentTheme)({
                    options: {
                        currentTheme: currentThemeName,
                        themes: themesList,
                    },
                }),
                (0, rules_1.currentBlocks)({
                    options: {
                        blocksList: uniqueBlocksList,
                    },
                }),
            ],
        },
        output: {
            library: ['Content', '[name]'],
            jsonpFunction: 'ewizardjsJsonp',
        },
        externals: {
            './app': {
                commonjs: ['Content', 'app'],
                commonjs2: ['Content', 'app'],
                root: ['Content', 'app'],
            },
            ComponentsList: 'ComponentsList',
        },
        plugins: [
            new plugins_1.ResetStatePlugin(presentationPath),
            new plugins_1.InjectCommonChunksPlugin(presentationPath),
            (0, plugins_1.cleanDestinationFolder)(cleanPatterns),
        ],
    };
    const { classic } = await (0, content_checker_1.getFrameworkInfo)(presentationPath);
    if (!classic) {
        cornConfig.module.rules.push((0, rules_2.entryEditor)({
            options: {
                blocksList: currentBlocksList,
            },
        }));
    }
    return (0, webpack_merge_1.mergeWithCustomize)({
        customizeArray: (0, webpack_merge_1.customizeArray)({
            'output.library': 'replace',
            'module.rules': 'prepend',
        }),
        customizeObject: (0, webpack_merge_1.customizeObject)({
            entry: 'replace',
            externals: 'replace',
        }),
    })(baseConfig, cornConfig);
};
//# sourceMappingURL=webpack.config.js.map