"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filename = void 0;
const plugins_1 = require("../plugins");
const upath_1 = require("@ewizardjs/upath");
const webpack_merge_1 = require("webpack-merge");
const utils_1 = require("../utils");
const PLUGINS_TO_REMOVE = [
    'CleanWebpackPlugin',
    'ValidateContentPathsPlugin',
    'InjectCommonChunksPlugin',
    'WebpackBarPlugin',
];
exports.filename = 'build/dev/templates.js';
exports.default = (presentationPath, config) => {
    const templatesConfig = getTemplatesConfig(presentationPath);
    return (0, webpack_merge_1.mergeWithCustomize)({
        customizeArray(item1, item2, key) {
            if (key === 'plugins') {
                const defaultPlugins = item1;
                const templatesPlugins = item2;
                return (0, utils_1.removePlugins)(defaultPlugins, PLUGINS_TO_REMOVE).concat(templatesPlugins);
            }
        },
    })(config, templatesConfig);
};
function getTemplatesConfig(presentationPath) {
    return {
        entry: require.resolve('../../assets/entry-templates.js'),
        mode: 'production',
        devtool: false,
        output: {
            filename: exports.filename,
            library: 'Templates',
            libraryTarget: 'window',
        },
        performance: {
            hints: false,
        },
        plugins: [
            (0, plugins_1.cleanDestinationFolder)([(0, upath_1.join)(presentationPath, exports.filename)]),
        ],
        externals: {
            ComponentsList: 'ComponentsList',
        },
        module: {
            rules: [
                {
                    test: /entry-templates.js/,
                    use: {
                        loader: require.resolve('../loaders/entry-banner-template-loader'),
                        options: {
                            presentationPath,
                        },
                    },
                },
            ]
        }
    };
}
//# sourceMappingURL=webpack.config.js.map