"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeRules = exports.removePlugins = exports.ensureComponentsListExists = exports.isString = exports.encodeFilePath = exports.toUnixPath = exports.uniqueId = exports.getEwizardjsVersion = exports.getNormalizedVueFileContent = void 0;
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
var builder_utils_1 = require("@ewizardjs/builder-utils");
Object.defineProperty(exports, "getNormalizedVueFileContent", { enumerable: true, get: function () { return builder_utils_1.getNormalizedVueFileContent; } });
async function getEwizardjsVersion(contentPath) {
    const ewizardjsPackagePath = (0, path_1.join)(contentPath, 'node_modules/ewizardjs/package.json');
    const ewizardjsPackage = await (0, fs_extra_1.readJson)(ewizardjsPackagePath);
    return ewizardjsPackage.version;
}
exports.getEwizardjsVersion = getEwizardjsVersion;
function uniqueId(length = 8, alphabet = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ') {
    let uniqueId = '';
    while (uniqueId.length < length) {
        uniqueId += alphabet.charAt(Math.floor(Math.random() * alphabet.length));
    }
    return uniqueId;
}
exports.uniqueId = uniqueId;
function toUnixPath(path) {
    return path.replace(/\\/g, '/');
}
exports.toUnixPath = toUnixPath;
function encodeFilePath(url) {
    try {
        return decodeSpace(encodeURI(decodeURI(url)));
    }
    catch (e) {
        return decodeSpace(encodeURI(url));
    }
}
exports.encodeFilePath = encodeFilePath;
function isString(value) {
    return typeof value === 'string' || value instanceof String;
}
exports.isString = isString;
async function ensureComponentsListExists(presentationPath) {
    const componentsJsPath = 'common/components/components.js';
    return await (0, fs_extra_1.pathExists)((0, path_1.join)(presentationPath, componentsJsPath));
}
exports.ensureComponentsListExists = ensureComponentsListExists;
function removePlugins(plugins = [], pluginsToRemove) {
    return plugins.filter(plugin => plugin.constructor && !pluginsToRemove.includes(plugin.constructor.name));
}
exports.removePlugins = removePlugins;
function removeRules(rules = [], rulesToRemove) {
    return rules.filter(rule => rule.test && !rulesToRemove.includes(rule.test.toString()));
}
exports.removeRules = removeRules;
function decodeSpace(url) {
    return url.replace(/%20/g, ' ');
}
//# sourceMappingURL=utils.js.map